@@ -1,5 +1,7 @@
 package WWW::Curl::Simple;
-our $VERSION = '0.100181';
+BEGIN {
+  $WWW::Curl::Simple::VERSION = '0.100182';
+}
 # ABSTRACT: A Simpler interface to WWW::Curl
 use Moose;
 
@@ -16,13 +18,11 @@ use namespace::clean -except => 'meta';
 
 
 
-
-
 sub request {
     my ($self, $req) = @_;
-    
+
     my $curl = WWW::Curl::Simple::Request->new(request => $req);
-    
+
     # Starts the actual request
     return $curl->perform;
 }
@@ -37,16 +37,16 @@ sub get {
 
 sub post {
     my ($self, $uri, $form) = @_;
-    
+
     return $self->request(HTTP::Request->new(POST => $uri, undef, $form));
 }
 
 
 
 has _requests => (
-    traits => ['Array'], 
-    is => 'ro', 
-    isa => 'ArrayRef[WWW::Curl::Simple::Request]', 
+    traits => ['Array'],
+    is => 'ro',
+    isa => 'ArrayRef[WWW::Curl::Simple::Request]',
     handles => {
         _add_request => 'push',
         requests => 'elements',
@@ -62,7 +62,7 @@ sub add_request {
     my ($self, $req) = @_;
     $req = WWW::Curl::Simple::Request->new(request => $req);
     $self->_add_request($req);
-    
+
     return $req;
 }
 
@@ -74,7 +74,7 @@ __PACKAGE__->meta->add_package_symbol('&register',
 
 sub has_request {
     my ($self, $req) = @_;
-    
+
     $self->_find_request(sub {
         $_ == $req
     });
@@ -83,11 +83,11 @@ sub has_request {
 
 sub delete_request {
     my ($self, $req) = @_;
-    
+
     return unless $self->has_request($req);
     # need to find the index
     my $c = $self->_count_requests;
-    
+
     while ($c--) {
         $self->_delete_request($c) if ($self->_get_request($c) == $req);
     }
@@ -98,9 +98,9 @@ sub delete_request {
 
 sub perform {
     my ($self) = @_;
-    
+
     my $curlm = WWW::Curl::Multi->new;
-    
+
     my %reqs;
     my $i = 0;
     foreach my $req ($self->requests) {
@@ -108,7 +108,7 @@ sub perform {
         my $curl = $req->easy;
         # we set this so we have the ref later on
         $curl->setopt(CURLOPT_PRIVATE, $i);
-        
+
         # here we also mangle all requests based on options
         # XXX: Should re-factor this to be a metaclass/trait on the attributes,
         # and a general method that takes all those and applies the propper setopt
@@ -118,14 +118,14 @@ sub perform {
                 croak( "Your trying to use timeout_ms, but your libcurl is apperantly older than 7.16.12.");
             }
             $curl->setopt($WWW::Curl::Easy::CURLOPT_TIMEOUT_MS, $self->timeout_ms) if $self->timeout_ms;
-            $curl->setopt($WWW::Curl::Easy::CURLOPT_CONNECTTIMEOUT_MS, $self->connection_timeout_ms) if $self->connection_timeout_ms;                
+            $curl->setopt($WWW::Curl::Easy::CURLOPT_CONNECTTIMEOUT_MS, $self->connection_timeout_ms) if $self->connection_timeout_ms;
         } else {
             $curl->setopt(CURLOPT_TIMEOUT, $self->timeout) if $self->timeout;
             $curl->setopt(CURLOPT_CONNECTTIMEOUT, $self->connection_timeout) if $self->connection_timeout;
         }
-        
+
         $curlm->add_handle($curl);
-        
+
         $reqs{$i} = $req;
     }
     my @res;
@@ -137,9 +137,9 @@ sub perform {
                     $i--;
                     my $req = $reqs{$id};
                     unless ($retcode == 0) {
-                        my $err = "Error during handeling of request: " 
+                        my $err = "Error during handeling of request: "
                             .$req->easy->strerror($retcode)." ". $req->request->uri;
-                        
+
                         croak($err) if $self->fatal;
                         carp($err) unless $self->fatal;
                     }
@@ -156,17 +156,17 @@ sub perform {
 
 sub wait {
     my $self = shift;
-    
+
     my @res = $self->perform(@_);
-    
+
     # convert to a hash
     my %res;
-    
+
     while (my $r = pop @res) {
         #warn "adding $r at " . scalar(@res);
         $res{scalar(@res)} = $r;
     }
-    
+
     return \%res;
 }
 
@@ -195,27 +195,27 @@ WWW::Curl::Simple - A Simpler interface to WWW::Curl
 
 =head1 VERSION
 
-version 0.100181
+version 0.100182
 
 =head1 SYNOPSIS
 
-It makes it easier to use WWW::Curl::(Easy|Multi), or so I hope
+Makes WWW::Curl::(Easy|Multi) easier to use.
 
     use WWW::Curl::Simple;
 
     my $curl = WWW::Curl::Simple->new();
-    
-    my $res = $curl->get('http://www.google.com/');
+
+    my $res  = $curl->get('http://www.google.com/');
 
 =head1 ATTRIBUTES
 
 =head2 timeout / timeout_ms
 
-Sets the timeout of individual requests, in seconds or milliseconds
+Sets the timeout of individual requests, in seconds or milliseconds.
 
 =head2 connection_timeout /connection_timeout_ms
 
-Sets the timeout of the connect phase of requests, in seconds or milliseconds
+Sets the timeout of the connect phase of requests, in seconds or milliseconds.
 
 =head2 fatal
 
@@ -226,60 +226,60 @@ warn instead of die.
 
 =head2 request($req)
 
-$req should be a  HTTP::Request object.
+C<$req> should be a L<HTTP::Request> object.
 
-If you have a URI-string or object, look at the get-method instead.
-Returns a L<HTTP::Response> object.
+If you have a URI string or object, look at the C<get> method instead.
+Returns a L<WWW::Curl::Simple::Request> object.
 
 =head2 get($uri || URI)
 
 Accepts one parameter, which should be a reference to a URI object or a
-string representing a uri. Returns a L<HTTP::Response> object.
+string representing a URI. Returns a L<HTTP::Response> object.
 
 =head2 post($uri || URI, $form)
 
-Created a HTTP::Request of type POST to $uri, which can be a string
-or a URI object, and sets the form of the request to $form. See
-L<HTTP::Request> for more information on the format of $form
+Creates a L<HTTP::Request> of type POST to C<$uri>, which can be a string
+or a URI object, and sets the form of the request to C<$form>. See
+L<HTTP::Request> for more information on the format of C<$form>.
 
 =head2 add_request($req)
 
-Adds $req (HTTP::Request) to the list of URL's to fetch. Returns a 
-L<WWW::Simple::Curl::Request>
+Adds C<$req> (a L<HTTP::Request> object) to the list of URLs to fetch. Returns
+a L<WWW::Simple::Curl::Request> object.
 
 =head2 register($req)
 
-This is just an alias for add_request
+An alias for C<add_request>.
 
 =head2 has_request $request
 
-Will return true if $request is one of our requests
+Will return true if C<$request> is one of the object's requests.
 
 =head2 delete_request $req
 
-Will remove $req from our list of requests
+Removes C<$req> from the object's list of requests.
 
 =head2 perform
 
-Does all the requests added with add_request, and returns a 
-list of HTTP::Response-objects
+Does all the requests added with C<add_request> and returns a list of
+L<WWW::Curl::Simple::Request> objects.
 
 =head2 wait
 
 These methods are here to provide an easier transition from
-L<LWP::Parallel::UserAgent>. It is by no means a drop in replacement,
-but using C<wait> instead of C<perform> makes the return-value perform
-more alike
+L<LWP::Parallel::UserAgent>. It is by no means a drop in replacement, but using
+C<wait> instead of C<perform> makes the return value more like that of
+LWP::PUA.
 
 =head1 LWP::Parallel::UserAgent compliant methods
 
 =head1 AUTHOR
 
-  Andreas Marienborg <andremar@cpan.org>
+Andreas Marienborg <andremar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Andreas Marienborg.
+This software is copyright (c) 2011 by Andreas Marienborg.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
